import _extends from "@babel/runtime/helpers/esm/extends";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import shallowEqual from "enzyme-shallow-equal";
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import PropTypes from 'prop-types';
import momentPropTypes from 'react-moment-proptypes';
import { forbidExtraProps, mutuallyExclusiveProps, nonNegativeInteger } from 'airbnb-prop-types';
import { withStyles, withStylesPropTypes } from 'react-with-styles';
import moment from 'moment';
import { addEventListener } from 'consolidated-events';
import { CalendarDayPhrases } from '../defaultPhrases';
import getPhrasePropTypes from '../utils/getPhrasePropTypes';
import noflip from '../utils/noflip';
import CalendarMonth from './CalendarMonth';
import isTransitionEndSupported from '../utils/isTransitionEndSupported';
import getTransformStyles from '../utils/getTransformStyles';
import getCalendarMonthWidth from '../utils/getCalendarMonthWidth';
import toISOMonthString from '../utils/toISOMonthString';
import isPrevMonth from '../utils/isPrevMonth';
import isNextMonth from '../utils/isNextMonth';
import ModifiersShape from '../shapes/ModifiersShape';
import ScrollableOrientationShape from '../shapes/ScrollableOrientationShape';
import DayOfWeekShape from '../shapes/DayOfWeekShape';
import { HORIZONTAL_ORIENTATION, VERTICAL_ORIENTATION, VERTICAL_SCROLLABLE, DAY_SIZE } from '../constants';
var propTypes = process.env.NODE_ENV !== "production" ? forbidExtraProps(_objectSpread(_objectSpread({}, withStylesPropTypes), {}, {
  enableOutsideDays: PropTypes.bool,
  firstVisibleMonthIndex: PropTypes.number,
  horizontalMonthPadding: nonNegativeInteger,
  initialMonth: momentPropTypes.momentObj,
  isAnimating: PropTypes.bool,
  numberOfMonths: PropTypes.number,
  modifiers: PropTypes.objectOf(PropTypes.objectOf(ModifiersShape)),
  orientation: ScrollableOrientationShape,
  onDayClick: PropTypes.func,
  onDayMouseEnter: PropTypes.func,
  onDayMouseLeave: PropTypes.func,
  onMonthTransitionEnd: PropTypes.func,
  onMonthChange: PropTypes.func,
  onYearChange: PropTypes.func,
  renderMonthText: mutuallyExclusiveProps(PropTypes.func, 'renderMonthText', 'renderMonthElement'),
  renderCalendarDay: PropTypes.func,
  renderDayContents: PropTypes.func,
  translationValue: PropTypes.number,
  renderMonthElement: mutuallyExclusiveProps(PropTypes.func, 'renderMonthText', 'renderMonthElement'),
  daySize: nonNegativeInteger,
  focusedDate: momentPropTypes.momentObj,
  // indicates focusable day
  isFocused: PropTypes.bool,
  // indicates whether or not to move focus to focusable day
  firstDayOfWeek: DayOfWeekShape,
  setMonthTitleHeight: PropTypes.func,
  isRTL: PropTypes.bool,
  transitionDuration: nonNegativeInteger,
  verticalBorderSpacing: nonNegativeInteger,
  // i18n
  monthFormat: PropTypes.string,
  phrases: PropTypes.shape(getPhrasePropTypes(CalendarDayPhrases)),
  dayAriaLabelFormat: PropTypes.string
})) : {};
var defaultProps = {
  enableOutsideDays: false,
  firstVisibleMonthIndex: 0,
  horizontalMonthPadding: 13,
  initialMonth: moment(),
  isAnimating: false,
  numberOfMonths: 1,
  modifiers: {},
  orientation: HORIZONTAL_ORIENTATION,
  onDayClick: function onDayClick() {},
  onDayMouseEnter: function onDayMouseEnter() {},
  onDayMouseLeave: function onDayMouseLeave() {},
  onMonthChange: function onMonthChange() {},
  onYearChange: function onYearChange() {},
  onMonthTransitionEnd: function onMonthTransitionEnd() {},
  renderMonthText: null,
  renderCalendarDay: undefined,
  renderDayContents: null,
  translationValue: null,
  renderMonthElement: null,
  daySize: DAY_SIZE,
  focusedDate: null,
  isFocused: false,
  firstDayOfWeek: null,
  setMonthTitleHeight: null,
  isRTL: false,
  transitionDuration: 200,
  verticalBorderSpacing: undefined,
  // i18n
  monthFormat: 'MMMM YYYY',
  // english locale
  phrases: CalendarDayPhrases,
  dayAriaLabelFormat: undefined
};
function getMonths(initialMonth, numberOfMonths, withoutTransitionMonths) {
  // console.log("initialMonth",initialMonth.format("YYYY-MM"));
  var month = initialMonth.clone();
  if (!withoutTransitionMonths) month = month.subtract(1, 'month');
  var months = [];
  for (var i = 0; i < (withoutTransitionMonths ? numberOfMonths : numberOfMonths + 2); i += 1) {
    months.push(month);
    month = month.clone().add(1, 'month');
  }
  return months;
}
var CalendarMonthGrid = /*#__PURE__*/function (_ref2, _ref) {
  _inheritsLoose(CalendarMonthGrid, _ref2);
  var _proto = CalendarMonthGrid.prototype;
  _proto[_ref] = function (nextProps, nextState) {
    return !shallowEqual(this.props, nextProps) || !shallowEqual(this.state, nextState);
  };
  function CalendarMonthGrid(props) {
    var _this;
    _this = _ref2.call(this, props) || this;
    var withoutTransitionMonths = props.orientation === VERTICAL_SCROLLABLE;
    _this.state = {
      months: getMonths(props.initialMonth, props.numberOfMonths, withoutTransitionMonths),
      initialMonth: props.initialMonth
    };
    // console.log("constructor CalendarMonthGrid",props.initialMonth.format("YYYY-MM"));
    _this.isTransitionEndSupported = isTransitionEndSupported();
    _this.onTransitionEnd = _this.onTransitionEnd.bind(_assertThisInitialized(_this));
    _this.setContainerRef = _this.setContainerRef.bind(_assertThisInitialized(_this));
    _this.locale = moment.locale();
    _this.onMonthSelect = _this.onMonthSelect.bind(_assertThisInitialized(_this));
    _this.onYearSelect = _this.onYearSelect.bind(_assertThisInitialized(_this));
    _this.loc_onNextMonthClick = _this.loc_onNextMonthClick.bind(_assertThisInitialized(_this));
    _this.loc_onPrevMonthClick = _this.loc_onPrevMonthClick.bind(_assertThisInitialized(_this));
    return _this;
  }
  _proto.componentDidMount = function componentDidMount() {
    // const { initialMonth, numberOfMonths, orientation } = this.props;
    // let newMonths = this.state.months;
    // if(orientation == "vertical"){
    //   let newMonths = getMonths(initialMonth, numberOfMonths, false);
    // }
    // console.log("didmount",newMonths);
    // this.setState({
    //   months:newMonths
    // });
    this.removeEventListener = addEventListener(this.container, 'transitionend', this.onTransitionEnd);
  };
  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _this2 = this;
    var _this$props = this.props,
      initialMonth = _this$props.initialMonth,
      numberOfMonths = _this$props.numberOfMonths,
      orientation = _this$props.orientation;
    var months = this.state.months;
    var prevInitialMonth = prevProps.initialMonth;
    var prevNumberOfMonths = prevProps.numberOfMonths;
    var hasMonthChanged = !prevInitialMonth.isSame(initialMonth, 'month');
    var hasNumberOfMonthsChanged = prevNumberOfMonths !== numberOfMonths;
    var newMonths = months;
    // if (this.props.initialMonth !== this.state.initialMonth) {
    //   console.log("hasMonthChanged all ok");
    // }
    // console.log("hasMonthChanged check",hasMonthChanged, " = ", prevInitialMonth.format("YYYY-MM"), " = ",initialMonth.format("YYYY-MM") ,this.state.initialMonth.format("YYYY-MM"));
    if (hasMonthChanged || hasNumberOfMonthsChanged) {
      if (hasMonthChanged && !hasNumberOfMonthsChanged) {
        if (isNextMonth(prevInitialMonth, initialMonth)) {
          newMonths = months.slice(1);
          newMonths.push(months[months.length - 1].clone().add(1, 'month'));
        } else if (isPrevMonth(prevInitialMonth, initialMonth)) {
          newMonths = months.slice(0, months.length - 1);
          newMonths.unshift(months[0].clone().subtract(1, 'month'));
        } else {
          var _withoutTransitionMonths = orientation === VERTICAL_SCROLLABLE;
          newMonths = getMonths(initialMonth, numberOfMonths, _withoutTransitionMonths);
        }
      }
      if (hasNumberOfMonthsChanged) {
        var _withoutTransitionMonths2 = orientation === VERTICAL_SCROLLABLE;
        newMonths = getMonths(initialMonth, numberOfMonths, _withoutTransitionMonths2);
      }
      var momentLocale = moment.locale();
      if (this.locale !== momentLocale) {
        this.locale = momentLocale;
        newMonths = newMonths.map(function (m) {
          return m.locale(_this2.locale);
        });
      }
      // console.log("set new months",newMonths);
      this.setState({
        months: newMonths
      });
    } else {
      if (hasMonthChanged) {
        // console.log("getMonths");
        newMonths = getMonths(initialMonth, numberOfMonths, withoutTransitionMonths);
        this.setState({
          months: newMonths
        });
      }
    }
    var _this$props2 = this.props,
      isAnimating = _this$props2.isAnimating,
      transitionDuration = _this$props2.transitionDuration,
      onMonthTransitionEnd = _this$props2.onMonthTransitionEnd;

    // For IE9, immediately call onMonthTransitionEnd instead of
    // waiting for the animation to complete. Similarly, if transitionDuration
    // is set to 0, also immediately invoke the onMonthTransitionEnd callback
    if ((!this.isTransitionEndSupported || !transitionDuration) && isAnimating) {
      onMonthTransitionEnd();
    }
  };
  _proto.componentWillUnmount = function componentWillUnmount() {
    if (this.removeEventListener) this.removeEventListener();
  };
  _proto.onTransitionEnd = function onTransitionEnd() {
    var onMonthTransitionEnd = this.props.onMonthTransitionEnd;
    onMonthTransitionEnd();
  };
  _proto.loc_onNextMonthClick = function loc_onNextMonthClick() {
    //onNextMonthClick

    var _this$props3 = this.props,
      onNextMonthClick = _this$props3.onNextMonthClick,
      initialMonth = _this$props3.initialMonth,
      orientation = _this$props3.orientation;
    // console.log("onNextMonthClick",initialMonth.format("YYYY-MM"));
    // if(orientation == "vertical"){
    //   initialMonth.add(4,"months");
    //   if(initialMonth < moment()){
    //     initialMonth = moment();
    //   }
    // }
    onNextMonthClick(initialMonth);
  };
  _proto.loc_onPrevMonthClick = function loc_onPrevMonthClick() {
    //onNextMonthClick
    // console.log("onPrevMonthClick");
    var _this$props4 = this.props,
      onPrevMonthClick = _this$props4.onPrevMonthClick,
      orientation = _this$props4.orientation;
    var initialMonth = this.props.initialMonth;
    onPrevMonthClick(initialMonth);
  };
  _proto.onMonthSelect = function onMonthSelect(currentMonth, newMonthVal) {
    var newMonth = currentMonth.clone();
    var _this$props5 = this.props,
      onMonthChange = _this$props5.onMonthChange,
      orientation = _this$props5.orientation;
    var months = this.state.months;
    var withoutTransitionMonths = orientation === VERTICAL_SCROLLABLE;
    var initialMonthSubtraction = months.indexOf(currentMonth);
    if (!withoutTransitionMonths) {
      initialMonthSubtraction -= 1;
    }
    newMonth.set('month', newMonthVal).subtract(initialMonthSubtraction, 'months');
    onMonthChange(newMonth);
  };
  _proto.onYearSelect = function onYearSelect(currentMonth, newYearVal) {
    var newMonth = currentMonth.clone();
    var _this$props6 = this.props,
      onYearChange = _this$props6.onYearChange,
      orientation = _this$props6.orientation;
    var months = this.state.months;
    var withoutTransitionMonths = orientation === VERTICAL_SCROLLABLE;
    var initialMonthSubtraction = months.indexOf(currentMonth);
    if (!withoutTransitionMonths) {
      initialMonthSubtraction -= 1;
    }
    newMonth.set('year', newYearVal).subtract(initialMonthSubtraction, 'months');
    onYearChange(newMonth);
  };
  _proto.setContainerRef = function setContainerRef(ref) {
    this.container = ref;
  };
  _proto.render = function render() {
    var _this3 = this;
    var _this$props7 = this.props,
      enableOutsideDays = _this$props7.enableOutsideDays,
      firstVisibleMonthIndex = _this$props7.firstVisibleMonthIndex,
      horizontalMonthPadding = _this$props7.horizontalMonthPadding,
      isAnimating = _this$props7.isAnimating,
      modifiers = _this$props7.modifiers,
      numberOfMonths = _this$props7.numberOfMonths,
      monthFormat = _this$props7.monthFormat,
      orientation = _this$props7.orientation,
      translationValue = _this$props7.translationValue,
      daySize = _this$props7.daySize,
      onDayMouseEnter = _this$props7.onDayMouseEnter,
      onDayMouseLeave = _this$props7.onDayMouseLeave,
      onDayClick = _this$props7.onDayClick,
      renderMonthText = _this$props7.renderMonthText,
      renderCalendarDay = _this$props7.renderCalendarDay,
      renderDayContents = _this$props7.renderDayContents,
      renderMonthElement = _this$props7.renderMonthElement,
      onMonthTransitionEnd = _this$props7.onMonthTransitionEnd,
      firstDayOfWeek = _this$props7.firstDayOfWeek,
      focusedDate = _this$props7.focusedDate,
      isFocused = _this$props7.isFocused,
      isRTL = _this$props7.isRTL,
      css = _this$props7.css,
      styles = _this$props7.styles,
      phrases = _this$props7.phrases,
      dayAriaLabelFormat = _this$props7.dayAriaLabelFormat,
      transitionDuration = _this$props7.transitionDuration,
      verticalBorderSpacing = _this$props7.verticalBorderSpacing,
      setMonthTitleHeight = _this$props7.setMonthTitleHeight,
      initialMonth = _this$props7.initialMonth,
      monthdataloading = _this$props7.monthdataloading;
    var _this$props8 = this.props,
      disableNext = _this$props8.disableNext,
      disablePrev = _this$props8.disablePrev,
      onNextMonthClick = _this$props8.onNextMonthClick,
      onPrevMonthClick = _this$props8.onPrevMonthClick;
    var months = this.state.months;
    var isVertical = orientation === VERTICAL_ORIENTATION;
    var isVerticalScrollable = orientation === VERTICAL_SCROLLABLE;
    var isHorizontal = orientation === HORIZONTAL_ORIENTATION;
    var calendarMonthWidth = getCalendarMonthWidth(daySize, horizontalMonthPadding);
    var width = isVertical || isVerticalScrollable ? calendarMonthWidth : (numberOfMonths + 2) * calendarMonthWidth;
    var transformType = isVertical || isVerticalScrollable ? 'translateY' : 'translateX';
    var transformValue = "".concat(transformType, "(").concat(translationValue, "px)");
    return /*#__PURE__*/React.createElement("div", _extends({}, css(styles.CalendarMonthGrid, isHorizontal && styles.CalendarMonthGrid__horizontal, isVertical && styles.CalendarMonthGrid__vertical, isVerticalScrollable && styles.CalendarMonthGrid__vertical_scrollable, isAnimating && styles.CalendarMonthGrid__animating, isAnimating && transitionDuration && {
      transition: "transform ".concat(transitionDuration, "ms ease-in-out 0.1s")
    }, _objectSpread(_objectSpread({}, getTransformStyles(transformValue)), {}, {
      width: width
    })), {
      ref: this.setContainerRef,
      onTransitionEnd: onMonthTransitionEnd
    }), initialMonth != null && initialMonth > moment() && /*#__PURE__*/React.createElement("div", {
      className: "col-md-12 DayPickerNavigation-vert",
      style: {
        padding: "0 15px"
      }
    }, /*#__PURE__*/React.createElement("button", {
      disabled: monthdataloading ? true : false,
      className: "btn btn-default",
      style: {
        width: "100%",
        position: "relative",
        zIndex: "9"
      },
      onClick: this.loc_onPrevMonthClick
    }, monthdataloading == true ? /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement("span", {
      className: "spinner-border spinner-border-left spinner-border-sm",
      role: "status"
    }), /*#__PURE__*/React.createElement("span", null, "Processing...")) : /*#__PURE__*/React.createElement("span", null, "Load more dates"))), months.map(function (month, i) {
      var isVisible = i >= firstVisibleMonthIndex && i < firstVisibleMonthIndex + numberOfMonths;
      var hideForAnimation = i === 0 && !isVisible;
      var showForAnimation = i === 0 && isAnimating && isVisible;
      var monthString = toISOMonthString(month);
      return /*#__PURE__*/React.createElement("div", _extends({
        key: monthString
      }, css(isHorizontal && styles.CalendarMonthGrid_month__horizontal, hideForAnimation && styles.CalendarMonthGrid_month__hideForAnimation, showForAnimation && !isVertical && !isRTL && {
        position: 'absolute',
        left: -calendarMonthWidth
      }, showForAnimation && !isVertical && isRTL && {
        position: 'absolute',
        right: 0
      }, showForAnimation && isVertical && {
        position: 'absolute',
        top: -translationValue
      }, !isVisible && !isAnimating && styles.CalendarMonthGrid_month__hidden)), /*#__PURE__*/React.createElement(CalendarMonth, {
        month: month,
        isVisible: isVisible,
        enableOutsideDays: enableOutsideDays,
        modifiers: modifiers[monthString],
        monthFormat: monthFormat,
        orientation: orientation,
        onDayMouseEnter: onDayMouseEnter,
        onDayMouseLeave: onDayMouseLeave,
        onDayClick: onDayClick,
        onMonthSelect: _this3.onMonthSelect,
        onYearSelect: _this3.onYearSelect,
        renderMonthText: renderMonthText,
        renderCalendarDay: renderCalendarDay,
        renderDayContents: renderDayContents,
        renderMonthElement: renderMonthElement,
        firstDayOfWeek: firstDayOfWeek,
        daySize: daySize,
        focusedDate: isVisible ? focusedDate : null,
        isFocused: isFocused,
        phrases: phrases,
        setMonthTitleHeight: setMonthTitleHeight,
        dayAriaLabelFormat: dayAriaLabelFormat,
        verticalBorderSpacing: verticalBorderSpacing,
        horizontalMonthPadding: horizontalMonthPadding
      }));
    }), /*#__PURE__*/React.createElement("div", {
      "class": "col-md-12 DayPickerNavigation-vert",
      style: {
        padding: "0 15px"
      }
    }, /*#__PURE__*/React.createElement("button", {
      disabled: monthdataloading ? true : false,
      "class": "btn btn-default",
      style: {
        width: "100%",
        position: "relative",
        zIndex: "9"
      },
      onClick: this.loc_onNextMonthClick
    }, monthdataloading == true ? /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement("span", {
      className: "spinner-border spinner-border-left spinner-border-sm",
      role: "status"
    }), /*#__PURE__*/React.createElement("span", null, "Processing...")) : /*#__PURE__*/React.createElement("span", null, "Load more dates"))));
  };
  return CalendarMonthGrid;
}(React.PureComponent || React.Component, !React.PureComponent && "shouldComponentUpdate");
CalendarMonthGrid.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
CalendarMonthGrid.defaultProps = defaultProps;
export default withStyles(function (_ref3) {
  var _ref3$reactDates = _ref3.reactDates,
    color = _ref3$reactDates.color,
    spacing = _ref3$reactDates.spacing,
    zIndex = _ref3$reactDates.zIndex;
  return {
    CalendarMonthGrid: {
      background: color.background,
      textAlign: noflip('left'),
      zIndex: zIndex
    },
    CalendarMonthGrid__animating: {
      zIndex: zIndex + 1
    },
    CalendarMonthGrid__horizontal: {
      position: 'absolute',
      left: noflip(spacing.dayPickerHorizontalPadding)
    },
    CalendarMonthGrid__vertical: {
      margin: '0 auto'
    },
    CalendarMonthGrid__vertical_scrollable: {
      margin: '0 auto'
    },
    CalendarMonthGrid_month__horizontal: {
      display: 'inline-block',
      verticalAlign: 'top',
      minHeight: '100%'
    },
    CalendarMonthGrid_month__hideForAnimation: {
      position: 'absolute',
      zIndex: zIndex - 1,
      opacity: 0,
      pointerEvents: 'none'
    },
    CalendarMonthGrid_month__hidden: {
      visibility: 'hidden'
    }
  };
}, {
  pureComponent: typeof React.PureComponent !== 'undefined'
})(CalendarMonthGrid);